//
//  Daemon for IVPN Client Desktop
//  https://github.com/ivpn/desktop-app
//
//  Created by Stelnykovych Alexandr.
//  Copyright (c) 2020 Privatus Limited.
//
//  This file is part of the Daemon for IVPN Client Desktop.
//
//  The Daemon for IVPN Client Desktop is free software: you can redistribute it and/or
//  modify it under the terms of the GNU General Public License as published by the Free
//  Software Foundation, either version 3 of the License, or (at your option) any later version.
//
//  The Daemon for IVPN Client Desktop is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
//  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
//  details.
//
//  You should have received a copy of the GNU General Public License
//  along with the Daemon for IVPN Client Desktop. If not, see <https://www.gnu.org/licenses/>.
//

// +build windows

package winlib

import "syscall"

// Layer GUIDs
var (
	FwpmLayerInboundIppacketV4              = syscall.GUID{Data1: 0xc86fd1bf, Data2: 0x21cd, Data3: 0x497e, Data4: [8]byte{0xa0, 0xbb, 0x17, 0x42, 0x5c, 0x88, 0x5c, 0x58}}
	FwpmLayerInboundIppacketV4Discard       = syscall.GUID{Data1: 0xb5a230d0, Data2: 0xa8c0, Data3: 0x44f2, Data4: [8]byte{0x91, 0x6e, 0x99, 0x1b, 0x53, 0xde, 0xd1, 0xf7}}
	FwpmLayerInboundIppacketV6              = syscall.GUID{Data1: 0xf52032cb, Data2: 0x991c, Data3: 0x46e7, Data4: [8]byte{0x97, 0x1d, 0x26, 0x01, 0x45, 0x9a, 0x91, 0xca}}
	FwpmLayerInboundIppacketV6Discard       = syscall.GUID{Data1: 0xbb24c279, Data2: 0x93b4, Data3: 0x47a2, Data4: [8]byte{0x83, 0xad, 0xae, 0x16, 0x98, 0xb5, 0x08, 0x85}}
	FwpmLayerOutboundIppacketV4             = syscall.GUID{Data1: 0x1e5c9fae, Data2: 0x8a84, Data3: 0x4135, Data4: [8]byte{0xa3, 0x31, 0x95, 0x0b, 0x54, 0x22, 0x9e, 0xcd}}
	FwpmLayerOutboundIppacketV4Discard      = syscall.GUID{Data1: 0x08e4bcb5, Data2: 0xb647, Data3: 0x48f3, Data4: [8]byte{0x95, 0x3c, 0xe5, 0xdd, 0xbd, 0x03, 0x93, 0x7e}}
	FwpmLayerOutboundIppacketV6             = syscall.GUID{Data1: 0xa3b3ab6b, Data2: 0x3564, Data3: 0x488c, Data4: [8]byte{0x91, 0x17, 0xf3, 0x4e, 0x82, 0x14, 0x27, 0x63}}
	FwpmLayerOutboundIppacketV6Discard      = syscall.GUID{Data1: 0x9513d7c4, Data2: 0xa934, Data3: 0x49dc, Data4: [8]byte{0x91, 0xa7, 0x6c, 0xcb, 0x80, 0xcc, 0x02, 0xe3}}
	FwpmLayerIpforwardV4                    = syscall.GUID{Data1: 0xa82acc24, Data2: 0x4ee1, Data3: 0x4ee1, Data4: [8]byte{0xb4, 0x65, 0xfd, 0x1d, 0x25, 0xcb, 0x10, 0xa4}}
	FwpmLayerIpforwardV4Discard             = syscall.GUID{Data1: 0x9e9ea773, Data2: 0x2fae, Data3: 0x4210, Data4: [8]byte{0x8f, 0x17, 0x34, 0x12, 0x9e, 0xf3, 0x69, 0xeb}}
	FwpmLayerIpforwardV6                    = syscall.GUID{Data1: 0x7b964818, Data2: 0x19c7, Data3: 0x493a, Data4: [8]byte{0xb7, 0x1f, 0x83, 0x2c, 0x36, 0x84, 0xd2, 0x8c}}
	FwpmLayerIpforwardV6Discard             = syscall.GUID{Data1: 0x31524a5d, Data2: 0x1dfe, Data3: 0x472f, Data4: [8]byte{0xbb, 0x93, 0x51, 0x8e, 0xe9, 0x45, 0xd8, 0xa2}}
	FwpmLayerInboundTransportV4             = syscall.GUID{Data1: 0x5926dfc8, Data2: 0xe3cf, Data3: 0x4426, Data4: [8]byte{0xa2, 0x83, 0xdc, 0x39, 0x3f, 0x5d, 0x0f, 0x9d}}
	FwpmLayerInboundTransportV4Discard      = syscall.GUID{Data1: 0xac4a9833, Data2: 0xf69d, Data3: 0x4648, Data4: [8]byte{0xb2, 0x61, 0x6d, 0xc8, 0x48, 0x35, 0xef, 0x39}}
	FwpmLayerInboundTransportV6             = syscall.GUID{Data1: 0x634a869f, Data2: 0xfc23, Data3: 0x4b90, Data4: [8]byte{0xb0, 0xc1, 0xbf, 0x62, 0x0a, 0x36, 0xae, 0x6f}}
	FwpmLayerInboundTransportV6Discard      = syscall.GUID{Data1: 0x2a6ff955, Data2: 0x3b2b, Data3: 0x49d2, Data4: [8]byte{0x98, 0x48, 0xad, 0x9d, 0x72, 0xdc, 0xaa, 0xb7}}
	FwpmLayerOutboundTransportV4            = syscall.GUID{Data1: 0x09e61aea, Data2: 0xd214, Data3: 0x46e2, Data4: [8]byte{0x9b, 0x21, 0xb2, 0x6b, 0x0b, 0x2f, 0x28, 0xc8}}
	FwpmLayerOutboundTransportV4Discard     = syscall.GUID{Data1: 0xc5f10551, Data2: 0xbdb0, Data3: 0x43d7, Data4: [8]byte{0xa3, 0x13, 0x50, 0xe2, 0x11, 0xf4, 0xd6, 0x8a}}
	FwpmLayerOutboundTransportV6            = syscall.GUID{Data1: 0xe1735bde, Data2: 0x013f, Data3: 0x4655, Data4: [8]byte{0xb3, 0x51, 0xa4, 0x9e, 0x15, 0x76, 0x2d, 0xf0}}
	FwpmLayerOutboundTransportV6Discard     = syscall.GUID{Data1: 0xf433df69, Data2: 0xccbd, Data3: 0x482e, Data4: [8]byte{0xb9, 0xb2, 0x57, 0x16, 0x56, 0x58, 0xc3, 0xb3}}
	FwpmLayerStreamV4                       = syscall.GUID{Data1: 0x3b89653c, Data2: 0xc170, Data3: 0x49e4, Data4: [8]byte{0xb1, 0xcd, 0xe0, 0xee, 0xee, 0xe1, 0x9a, 0x3e}}
	FwpmLayerStreamV4Discard                = syscall.GUID{Data1: 0x25c4c2c2, Data2: 0x25ff, Data3: 0x4352, Data4: [8]byte{0x82, 0xf9, 0xc5, 0x4a, 0x4a, 0x47, 0x26, 0xdc}}
	FwpmLayerStreamV6                       = syscall.GUID{Data1: 0x47c9137a, Data2: 0x7ec4, Data3: 0x46b3, Data4: [8]byte{0xb6, 0xe4, 0x48, 0xe9, 0x26, 0xb1, 0xed, 0xa4}}
	FwpmLayerStreamV6Discard                = syscall.GUID{Data1: 0x10a59fc7, Data2: 0xb628, Data3: 0x4c41, Data4: [8]byte{0x9e, 0xb8, 0xcf, 0x37, 0xd5, 0x51, 0x03, 0xcf}}
	FwpmLayerDatagramDataV4                 = syscall.GUID{Data1: 0x3d08bf4e, Data2: 0x45f6, Data3: 0x4930, Data4: [8]byte{0xa9, 0x22, 0x41, 0x70, 0x98, 0xe2, 0x00, 0x27}}
	FwpmLayerDatagramDataV4Discard          = syscall.GUID{Data1: 0x18e330c6, Data2: 0x7248, Data3: 0x4e52, Data4: [8]byte{0xaa, 0xab, 0x47, 0x2e, 0xd6, 0x77, 0x04, 0xfd}}
	FwpmLayerDatagramDataV6                 = syscall.GUID{Data1: 0xfa45fe2f, Data2: 0x3cba, Data3: 0x4427, Data4: [8]byte{0x87, 0xfc, 0x57, 0xb9, 0xa4, 0xb1, 0x0d, 0x00}}
	FwpmLayerDatagramDataV6Discard          = syscall.GUID{Data1: 0x09d1dfe1, Data2: 0x9b86, Data3: 0x4a42, Data4: [8]byte{0xbe, 0x9d, 0x8c, 0x31, 0x5b, 0x92, 0xa5, 0xd0}}
	FwpmLayerInboundIcmpErrorV4             = syscall.GUID{Data1: 0x61499990, Data2: 0x3cb6, Data3: 0x4e84, Data4: [8]byte{0xb9, 0x50, 0x53, 0xb9, 0x4b, 0x69, 0x64, 0xf3}}
	FwpmLayerInboundIcmpErrorV4Discard      = syscall.GUID{Data1: 0xa6b17075, Data2: 0xebaf, Data3: 0x4053, Data4: [8]byte{0xa4, 0xe7, 0x21, 0x3c, 0x81, 0x21, 0xed, 0xe5}}
	FwpmLayerInboundIcmpErrorV6             = syscall.GUID{Data1: 0x65f9bdff, Data2: 0x3b2d, Data3: 0x4e5d, Data4: [8]byte{0xb8, 0xc6, 0xc7, 0x20, 0x65, 0x1f, 0xe8, 0x98}}
	FwpmLayerInboundIcmpErrorV6Discard      = syscall.GUID{Data1: 0xa6e7ccc0, Data2: 0x08fb, Data3: 0x468d, Data4: [8]byte{0xa4, 0x72, 0x97, 0x71, 0xd5, 0x59, 0x5e, 0x09}}
	FwpmLayerOutboundIcmpErrorV4            = syscall.GUID{Data1: 0x41390100, Data2: 0x564c, Data3: 0x4b32, Data4: [8]byte{0xbc, 0x1d, 0x71, 0x80, 0x48, 0x35, 0x4d, 0x7c}}
	FwpmLayerOutboundIcmpErrorV4Discard     = syscall.GUID{Data1: 0xb3598d36, Data2: 0x0561, Data3: 0x4588, Data4: [8]byte{0xa6, 0xbf, 0xe9, 0x55, 0xe3, 0xf6, 0x26, 0x4b}}
	FwpmLayerOutboundIcmpErrorV6            = syscall.GUID{Data1: 0x7fb03b60, Data2: 0x7b8d, Data3: 0x4dfa, Data4: [8]byte{0xba, 0xdd, 0x98, 0x01, 0x76, 0xfc, 0x4e, 0x12}}
	FwpmLayerOutboundIcmpErrorV6Discard     = syscall.GUID{Data1: 0x65f2e647, Data2: 0x8d0c, Data3: 0x4f47, Data4: [8]byte{0xb1, 0x9b, 0x33, 0xa4, 0xd3, 0xf1, 0x35, 0x7c}}
	FwpmLayerAleResourceAssignmentV4        = syscall.GUID{Data1: 0x1247d66d, Data2: 0x0b60, Data3: 0x4a15, Data4: [8]byte{0x8d, 0x44, 0x71, 0x55, 0xd0, 0xf5, 0x3a, 0x0c}}
	FwpmLayerAleResourceAssignmentV4Discard = syscall.GUID{Data1: 0x0b5812a2, Data2: 0xc3ff, Data3: 0x4eca, Data4: [8]byte{0xb8, 0x8d, 0xc7, 0x9e, 0x20, 0xac, 0x63, 0x22}}
	FwpmLayerAleResourceAssignmentV6        = syscall.GUID{Data1: 0x55a650e1, Data2: 0x5f0a, Data3: 0x4eca, Data4: [8]byte{0xa6, 0x53, 0x88, 0xf5, 0x3b, 0x26, 0xaa, 0x8c}}
	FwpmLayerAleResourceAssignmentV6Discard = syscall.GUID{Data1: 0xcbc998bb, Data2: 0xc51f, Data3: 0x4c1a, Data4: [8]byte{0xbb, 0x4f, 0x97, 0x75, 0xfc, 0xac, 0xab, 0x2f}}
	FwpmLayerAleAuthListenV4                = syscall.GUID{Data1: 0x88bb5dad, Data2: 0x76d7, Data3: 0x4227, Data4: [8]byte{0x9c, 0x71, 0xdf, 0x0a, 0x3e, 0xd7, 0xbe, 0x7e}}
	FwpmLayerAleAuthListenV4Discard         = syscall.GUID{Data1: 0x371dfada, Data2: 0x9f26, Data3: 0x45fd, Data4: [8]byte{0xb4, 0xeb, 0xc2, 0x9e, 0xb2, 0x12, 0x89, 0x3f}}
	FwpmLayerAleAuthListenV6                = syscall.GUID{Data1: 0x7ac9de24, Data2: 0x17dd, Data3: 0x4814, Data4: [8]byte{0xb4, 0xbd, 0xa9, 0xfb, 0xc9, 0x5a, 0x32, 0x1b}}
	FwpmLayerAleAuthListenV6Discard         = syscall.GUID{Data1: 0x60703b07, Data2: 0x63c8, Data3: 0x48e9, Data4: [8]byte{0xad, 0xa3, 0x12, 0xb1, 0xaf, 0x40, 0xa6, 0x17}}
	FwpmLayerAleAuthRecvAcceptV4            = syscall.GUID{Data1: 0xe1cd9fe7, Data2: 0xf4b5, Data3: 0x4273, Data4: [8]byte{0x96, 0xc0, 0x59, 0x2e, 0x48, 0x7b, 0x86, 0x50}}
	FwpmLayerAleAuthRecvAcceptV4Discard     = syscall.GUID{Data1: 0x9eeaa99b, Data2: 0xbd22, Data3: 0x4227, Data4: [8]byte{0x91, 0x9f, 0x00, 0x73, 0xc6, 0x33, 0x57, 0xb1}}
	FwpmLayerAleAuthRecvAcceptV6            = syscall.GUID{Data1: 0xa3b42c97, Data2: 0x9f04, Data3: 0x4672, Data4: [8]byte{0xb8, 0x7e, 0xce, 0xe9, 0xc4, 0x83, 0x25, 0x7f}}
	FwpmLayerAleAuthRecvAcceptV6Discard     = syscall.GUID{Data1: 0x89455b97, Data2: 0xdbe1, Data3: 0x453f, Data4: [8]byte{0xa2, 0x24, 0x13, 0xda, 0x89, 0x5a, 0xf3, 0x96}}
	FwpmLayerAleAuthConnectV4               = syscall.GUID{Data1: 0xc38d57d1, Data2: 0x05a7, Data3: 0x4c33, Data4: [8]byte{0x90, 0x4f, 0x7f, 0xbc, 0xee, 0xe6, 0x0e, 0x82}}
	FwpmLayerAleAuthConnectV4Discard        = syscall.GUID{Data1: 0xd632a801, Data2: 0xf5ba, Data3: 0x4ad6, Data4: [8]byte{0x96, 0xe3, 0x60, 0x70, 0x17, 0xd9, 0x83, 0x6a}}
	FwpmLayerAleAuthConnectV6               = syscall.GUID{Data1: 0x4a72393b, Data2: 0x319f, Data3: 0x44bc, Data4: [8]byte{0x84, 0xc3, 0xba, 0x54, 0xdc, 0xb3, 0xb6, 0xb4}}
	FwpmLayerAleAuthConnectV6Discard        = syscall.GUID{Data1: 0xc97bc3b8, Data2: 0xc9a3, Data3: 0x4e33, Data4: [8]byte{0x86, 0x95, 0x8e, 0x17, 0xaa, 0xd4, 0xde, 0x09}}
	FwpmLayerAleFlowEstablishedV4           = syscall.GUID{Data1: 0xaf80470a, Data2: 0x5596, Data3: 0x4c13, Data4: [8]byte{0x99, 0x92, 0x53, 0x9e, 0x6f, 0xe5, 0x79, 0x67}}
	FwpmLayerAleFlowEstablishedV4Discard    = syscall.GUID{Data1: 0x146ae4a9, Data2: 0xa1d2, Data3: 0x4d43, Data4: [8]byte{0xa3, 0x1a, 0x4c, 0x42, 0x68, 0x2b, 0x8e, 0x4f}}
	FwpmLayerAleFlowEstablishedV6           = syscall.GUID{Data1: 0x7021d2b3, Data2: 0xdfa4, Data3: 0x406e, Data4: [8]byte{0xaf, 0xeb, 0x6a, 0xfa, 0xf7, 0xe7, 0x0e, 0xfd}}
	FwpmLayerAleFlowEstablishedV6Discard    = syscall.GUID{Data1: 0x46928636, Data2: 0xbbca, Data3: 0x4b76, Data4: [8]byte{0x94, 0x1d, 0x0f, 0xa7, 0xf5, 0xd7, 0xd3, 0x72}}
	FwpmLayerInboundMacFrameEthernet        = syscall.GUID{Data1: 0xeffb7edb, Data2: 0x0055, Data3: 0x4f9a, Data4: [8]byte{0xa2, 0x3a, 0x4f, 0xf8, 0x13, 0x1a, 0xd1, 0x91}}
	FwpmLayerOutboundMacFrameEthernet       = syscall.GUID{Data1: 0x694673bc, Data2: 0xd6db, Data3: 0x4870, Data4: [8]byte{0xad, 0xee, 0x0a, 0xcd, 0xbd, 0xb7, 0xf4, 0xb2}}
	FwpmLayerInboundMacFrameNative          = syscall.GUID{Data1: 0xd4220bd3, Data2: 0x62ce, Data3: 0x4f08, Data4: [8]byte{0xae, 0x88, 0xb5, 0x6e, 0x85, 0x26, 0xdf, 0x50}}
	FwpmLayerOutboundMacFrameNative         = syscall.GUID{Data1: 0x94c44912, Data2: 0x9d6f, Data3: 0x4ebf, Data4: [8]byte{0xb9, 0x95, 0x05, 0xab, 0x8a, 0x08, 0x8d, 0x1b}}
	FwpmLayerIngressVswitchEthernet         = syscall.GUID{Data1: 0x7d98577a, Data2: 0x9a87, Data3: 0x41ec, Data4: [8]byte{0x97, 0x18, 0x7c, 0xf5, 0x89, 0xc9, 0xf3, 0x2d}}
	FwpmLayerEgressVswitchEthernet          = syscall.GUID{Data1: 0x86c872b0, Data2: 0x76fa, Data3: 0x4b79, Data4: [8]byte{0x93, 0xa4, 0x07, 0x50, 0x53, 0x0a, 0xe2, 0x92}}
	FwpmLayerIngressVswitchTransportV4      = syscall.GUID{Data1: 0xb2696ff6, Data2: 0x774f, Data3: 0x4554, Data4: [8]byte{0x9f, 0x7d, 0x3d, 0xa3, 0x94, 0x5f, 0x8e, 0x85}}
	FwpmLayerIngressVswitchTransportV6      = syscall.GUID{Data1: 0x5ee314fc, Data2: 0x7d8a, Data3: 0x47f4, Data4: [8]byte{0xb7, 0xe3, 0x29, 0x1a, 0x36, 0xda, 0x4e, 0x12}}
	FwpmLayerEgressVswitchTransportV4       = syscall.GUID{Data1: 0xb92350b6, Data2: 0x91f0, Data3: 0x46b6, Data4: [8]byte{0xbd, 0xc4, 0x87, 0x1d, 0xfd, 0x4a, 0x7c, 0x98}}
	FwpmLayerEgressVswitchTransportV6       = syscall.GUID{Data1: 0x1b2def23, Data2: 0x1881, Data3: 0x40bd, Data4: [8]byte{0x82, 0xf4, 0x42, 0x54, 0xe6, 0x31, 0x41, 0xcb}}
	FwpmLayerInboundTransportFast           = syscall.GUID{Data1: 0xe41d2719, Data2: 0x05c7, Data3: 0x40f0, Data4: [8]byte{0x89, 0x83, 0xea, 0x8d, 0x17, 0xbb, 0xc2, 0xf6}}
	FwpmLayerOutboundTransportFast          = syscall.GUID{Data1: 0x13ed4388, Data2: 0xa070, Data3: 0x4815, Data4: [8]byte{0x99, 0x35, 0x7a, 0x9b, 0xe6, 0x40, 0x8b, 0x78}}
	FwpmLayerInboundMacFrameNativeFast      = syscall.GUID{Data1: 0x853aaa8e, Data2: 0x2b78, Data3: 0x4d24, Data4: [8]byte{0xa8, 0x04, 0x36, 0xdb, 0x08, 0xb2, 0x97, 0x11}}
	FwpmLayerOutboundMacFrameNativeFast     = syscall.GUID{Data1: 0x470df946, Data2: 0xc962, Data3: 0x486f, Data4: [8]byte{0x94, 0x46, 0x82, 0x93, 0xcb, 0xc7, 0x5e, 0xb8}}
	FwpmLayerIpsecKmDemuxV4                 = syscall.GUID{Data1: 0xf02b1526, Data2: 0xa459, Data3: 0x4a51, Data4: [8]byte{0xb9, 0xe3, 0x75, 0x9d, 0xe5, 0x2b, 0x9d, 0x2c}}
	FwpmLayerIpsecKmDemuxV6                 = syscall.GUID{Data1: 0x2f755cf6, Data2: 0x2fd4, Data3: 0x4e88, Data4: [8]byte{0xb3, 0xe4, 0xa9, 0x1b, 0xca, 0x49, 0x52, 0x35}}
	FwpmLayerIpsecV4                        = syscall.GUID{Data1: 0xeda65c74, Data2: 0x610d, Data3: 0x4bc5, Data4: [8]byte{0x94, 0x8f, 0x3c, 0x4f, 0x89, 0x55, 0x68, 0x67}}
	FwpmLayerIpsecV6                        = syscall.GUID{Data1: 0x13c48442, Data2: 0x8d87, Data3: 0x4261, Data4: [8]byte{0x9a, 0x29, 0x59, 0xd2, 0xab, 0xc3, 0x48, 0xb4}}
	FwpmLayerIkeextV4                       = syscall.GUID{Data1: 0xb14b7bdb, Data2: 0xdbbd, Data3: 0x473e, Data4: [8]byte{0xbe, 0xd4, 0x8b, 0x47, 0x08, 0xd4, 0xf2, 0x70}}
	FwpmLayerIkeextV6                       = syscall.GUID{Data1: 0xb64786b3, Data2: 0xf687, Data3: 0x4eb9, Data4: [8]byte{0x89, 0xd2, 0x8e, 0xf3, 0x2a, 0xcd, 0xab, 0xe2}}
	FwpmLayerRPCUm                          = syscall.GUID{Data1: 0x75a89dda, Data2: 0x95e4, Data3: 0x40f3, Data4: [8]byte{0xad, 0xc7, 0x76, 0x88, 0xa9, 0xc8, 0x47, 0xe1}}
	FwpmLayerRPCEpmap                       = syscall.GUID{Data1: 0x9247bc61, Data2: 0xeb07, Data3: 0x47ee, Data4: [8]byte{0x87, 0x2c, 0xbf, 0xd7, 0x8b, 0xfd, 0x16, 0x16}}
	FwpmLayerRPCEpAdd                       = syscall.GUID{Data1: 0x618dffc7, Data2: 0xc450, Data3: 0x4943, Data4: [8]byte{0x95, 0xdb, 0x99, 0xb4, 0xc1, 0x6a, 0x55, 0xd4}}
	FwpmLayerRPCProxyConn                   = syscall.GUID{Data1: 0x94a4b50b, Data2: 0xba5c, Data3: 0x4f27, Data4: [8]byte{0x90, 0x7a, 0x22, 0x9f, 0xac, 0x0c, 0x2a, 0x7a}}
	FwpmLayerRPCProxyIf                     = syscall.GUID{Data1: 0xf8a38615, Data2: 0xe12c, Data3: 0x41ac, Data4: [8]byte{0x98, 0xdf, 0x12, 0x1a, 0xd9, 0x81, 0xaa, 0xde}}
	FwpmLayerKmAuthorization                = syscall.GUID{Data1: 0x4aa226e9, Data2: 0x9020, Data3: 0x45fb, Data4: [8]byte{0x95, 0x6a, 0xc0, 0x24, 0x9d, 0x84, 0x11, 0x95}}
	FwpmLayerNameResolutionCacheV4          = syscall.GUID{Data1: 0x0c2aa681, Data2: 0x905b, Data3: 0x4ccd, Data4: [8]byte{0xa4, 0x67, 0x4d, 0xd8, 0x11, 0xd0, 0x7b, 0x7b}}
	FwpmLayerNameResolutionCacheV6          = syscall.GUID{Data1: 0x92d592fa, Data2: 0x6b01, Data3: 0x434a, Data4: [8]byte{0x9d, 0xea, 0xd1, 0xe9, 0x6e, 0xa9, 0x7d, 0xa9}}
	FwpmLayerAleResourceReleaseV4           = syscall.GUID{Data1: 0x74365cce, Data2: 0xccb0, Data3: 0x401a, Data4: [8]byte{0xbf, 0xc1, 0xb8, 0x99, 0x34, 0xad, 0x7e, 0x15}}
	FwpmLayerAleResourceReleaseV6           = syscall.GUID{Data1: 0xf4e5ce80, Data2: 0xedcc, Data3: 0x4e13, Data4: [8]byte{0x8a, 0x2f, 0xb9, 0x14, 0x54, 0xbb, 0x05, 0x7b}}
	FwpmLayerAleEndpointClosureV4           = syscall.GUID{Data1: 0xb4766427, Data2: 0xe2a2, Data3: 0x467a, Data4: [8]byte{0xbd, 0x7e, 0xdb, 0xcd, 0x1b, 0xd8, 0x5a, 0x09}}
	FwpmLayerAleEndpointClosureV6           = syscall.GUID{Data1: 0xbb536ccd, Data2: 0x4755, Data3: 0x4ba9, Data4: [8]byte{0x9f, 0xf7, 0xf9, 0xed, 0xf8, 0x69, 0x9c, 0x7b}}
	FwpmLayerAleConnectRedirectV4           = syscall.GUID{Data1: 0xc6e63c8c, Data2: 0xb784, Data3: 0x4562, Data4: [8]byte{0xaa, 0x7d, 0x0a, 0x67, 0xcf, 0xca, 0xf9, 0xa3}}
	FwpmLayerAleConnectRedirectV6           = syscall.GUID{Data1: 0x587e54a7, Data2: 0x8046, Data3: 0x42ba, Data4: [8]byte{0xa0, 0xaa, 0xb7, 0x16, 0x25, 0x0f, 0xc7, 0xfd}}
	FwpmLayerAleBindRedirectV4              = syscall.GUID{Data1: 0x66978cad, Data2: 0xc704, Data3: 0x42ac, Data4: [8]byte{0x86, 0xac, 0x7c, 0x1a, 0x23, 0x1b, 0xd2, 0x53}}
	FwpmLayerAleBindRedirectV6              = syscall.GUID{Data1: 0xbef02c9c, Data2: 0x606b, Data3: 0x4536, Data4: [8]byte{0x8c, 0x26, 0x1c, 0x2f, 0xc7, 0xb6, 0x31, 0xd4}}
	FwpmLayerStreamPacketV4                 = syscall.GUID{Data1: 0xaf52d8ec, Data2: 0xcb2d, Data3: 0x44e5, Data4: [8]byte{0xad, 0x92, 0xf8, 0xdc, 0x38, 0xd2, 0xeb, 0x29}}
	FwpmLayerStreamPacketV6                 = syscall.GUID{Data1: 0x779a8ca3, Data2: 0xf099, Data3: 0x468f, Data4: [8]byte{0xb5, 0xd4, 0x83, 0x53, 0x5c, 0x46, 0x1c, 0x02}}
)
